@@ -15,7 +15,24 @@
 //
 //--------------------------------------------------------------------------------
 
+#include "AppleUSBAudioCommon.h"
 #include "AppleUSBAudioDevice.h"
+#include "AppleUSBAudioLevelControl.h"
+#include "AppleUSBAudioMuteControl.h"
+#include "USBAudioObject.h"
+#include "AppleUSBAudioEngine.h"
+
+#include <IOKit/IOLib.h>
+#include <IOKit/IOKitKeys.h>
+#include <IOKit/IORegistryEntry.h>
+#include <IOKit/audio/IOAudioStream.h>
+#include <IOKit/audio/IOAudioDefines.h>
+
+#include <IOKit/usb/IOUSBInterface.h>
+#include <IOKit/usb/IOUSBRootHubDevice.h>
+#include <IOKit/IOMessage.h>
+
+#include <libkern/c++/OSCollectionIterator.h>
 
 #define super IOAudioDevice
 
@@ -81,7 +98,7 @@ void AppleUSBAudioDevice::free () {
 
     if (usbAudio) {
         usbAudio->release ();
-        usbAudio = NULL;
+        usbAudio = 0;
     }
 
     super::free ();
@@ -94,70 +111,35 @@ bool AppleUSBAudioDevice::requestTerminate (IOService * provider, IOOptionBits o
 	return TRUE;		// it is OK to terminate us
 }
 
-bool AppleUSBAudioDevice::ControlsStreamNumber (UInt8 streamNumber) {
-	UInt8 *							streamNumbers;
-	UInt8							numStreams;
-	UInt8							index;
-	bool							doesControl;
-
-	doesControl = FALSE;
-
-	if (usbAudio) {
-		usbAudio->GetControlledStreamNumbers (&streamNumbers, &numStreams);
-		for (index = 0; index < numStreams; index++) {
-			debug3IOLog ("Checking stream %d against controled stream %d\n", streamNumber, streamNumbers[index]);
-			if (streamNumber == streamNumbers[index]) {
-				doesControl = TRUE;
-				break;				// get out of for loop
-			}
-		}
-	}
-
-	return doesControl;
-}
-
 bool AppleUSBAudioDevice::start (IOService * provider) {
     OSObject *						obj;
 	UInt8							stringIndex;
 	char							string[kStringBufferSize];
 	IOReturn						err;
     Boolean							resultCode;
-	UInt8 *							streamNumbers;
-	UInt8							numStreams;
 
 	debug3IOLog ("+AppleUSBAudioDevice[%p]::start (%p)\n", this, provider);
 
 	resultCode = FALSE;
 
 	controlInterface = OSDynamicCast (IOUSBInterface, provider);
-	FailIf (FALSE == controlInterface->open (this), Exit);
+	FailIf (NULL == controlInterface, Exit);
+	previousInterface = controlInterface;
 
 	debug2IOLog ("There are %d configurations on this device\n", controlInterface->GetDevice()->GetNumConfigurations ());
-	debug2IOLog ("Our control interface number is %d\n", controlInterface->GetInterfaceNumber ());
-	usbAudio = USBAudioConfigObject::create (controlInterface->GetDevice()->GetFullConfigurationDescriptor (0), controlInterface->GetInterfaceNumber ());
+	usbAudio = USBAudioConfigObject::create (controlInterface->GetDevice()->GetFullConfigurationDescriptor (0));
 	FailIf (NULL == usbAudio, Exit);
 
-	// Check to make sure that the control interface we loaded against has audio streaming interfaces and not just MIDI.
-	usbAudio->GetControlledStreamNumbers (&streamNumbers, &numStreams);
-	debug2IOLog ("Num streams controlled = %d\n", numStreams);
-	debug2IOLog ("GetNumStreamInterfaces = %d\n", usbAudio->GetNumStreamInterfaces ());
-	FailIf (0 == numStreams, Exit);
-
 	// If this is an iSub, we need to not go any further because we don't support it in this driver
 	// This will cause the driver to not load on any device that has _only_ a low frequency effect output terminal
 	FailIf (usbAudio->GetNumOutputTerminals (0, 0) == 1 && usbAudio->GetIndexedOutputTerminalType (0, 0, 0) == OUTPUT_LOW_FREQUENCY_EFFECTS_SPEAKER, Exit);
 
 	err = kIOReturnError;
 	string[0] = 0;
-	stringIndex = controlInterface->GetInterfaceStringIndex ();
-	if (0 != stringIndex) {
-		err = controlInterface->GetDevice()->GetStringDescriptor (stringIndex, string, kStringBufferSize);
-	} else {
 	stringIndex = controlInterface->GetDevice()->GetProductStringIndex ();
 	if (0 != stringIndex) {
 		err = controlInterface->GetDevice()->GetStringDescriptor (stringIndex, string, kStringBufferSize);
 	}
-	}
 
 	if (0 == string[0] || kIOReturnSuccess != err) {
 		strcpy (string, "Unknown USB Audio Device");
@@ -179,6 +161,10 @@ bool AppleUSBAudioDevice::start (IOService * provider) {
 	setManufacturerName (string);
 	setDeviceTransportType (kIOAudioDeviceTransportTypeUSB);
 
+	FailIf (FALSE == controlInterface->open (this), Exit);
+	// get the IOAudioDevice generic start routine
+	FailIf (FALSE == super::start (provider), Exit);
+
 	interfaceLock = IORecursiveLockAlloc ();
 	FailIf (NULL == interfaceLock, Exit);
 
@@ -207,7 +193,6 @@ bool AppleUSBAudioDevice::start (IOService * provider) {
 		interfaceNumber = obj;
 	}
 
-	FailIf (FALSE == super::start (provider), Exit);
 	resultCode = TRUE;
 
 Exit:
@@ -215,6 +200,50 @@ Exit:
 	return resultCode;
 }
 
+void AppleUSBAudioDevice::streamStopped (IOAudioEngine *audioEngine) {
+    // This must be called from within the workLoop
+    // The AppleUSBAudioEngine does so from _setState()
+    // which has the same requirement
+    debugIOLog ("+AppleUSBAudioDevice::streamStopped ()\n");
+    
+    if (allStreamsStopped()) {
+        terminate();
+    }
+    
+    debugIOLog ("-AppleUSBAudioDevice::streamStopped ()\n");
+}
+
+bool AppleUSBAudioDevice::allStreamsStopped () {
+    OSCollectionIterator *			audioEngineIterator;
+    IOAudioEngine *					audioEngine;
+    bool							result;
+
+    debug2IOLog ("+AppleUSBAudioDevice[%p]::allStreamsStopped ()\n", this);
+    result = TRUE;
+
+    FailIf (NULL == audioEngines, Exit);
+
+    // Need to do this on the IOWorkLoop
+    
+    audioEngineIterator = OSCollectionIterator::withCollection (audioEngines);
+
+    if (audioEngineIterator) {
+        while (audioEngine = (IOAudioEngine *)audioEngineIterator->getNextObject ()) {
+            if (OSDynamicCast (AppleUSBAudioEngine, audioEngine)) {	// We only care that the AppleUSBAudioEngines are stopped
+                if (audioEngine->getState () != kIOAudioEngineStopped) {
+                    result = FALSE;
+                    break;
+                }
+            }
+        }
+        audioEngineIterator->release ();
+    }
+
+Exit:
+    debug2IOLog ("-AppleUSBAudioDevice[%p]::allStreamsStopped ()\n", this);
+    return result;
+}
+
 IOReturn AppleUSBAudioDevice::performPowerStateChange (IOAudioDevicePowerState oldPowerState, IOAudioDevicePowerState newPowerState, UInt32 *microSecsUntilComplete) {
 	IOReturn						result;
 
@@ -442,8 +471,6 @@ IOReturn AppleUSBAudioDevice::createControlsForInterface (IOAudioEngine *audioEn
 	UInt8								controlInterfaceNum;
 	Boolean								shouldUpdatePRAM;
 
-    debug4IOLog ("+AppleUSBAudioDevice[%p]::createControlsForInterface %d %d\n", this, interfaceNum, altInterfaceNum);
-
     result = kIOReturnError;
 	terminatingDriver = FALSE;
 	FailIf (NULL == controlInterface, Exit);
@@ -548,7 +575,6 @@ IOReturn AppleUSBAudioDevice::createControlsForInterface (IOAudioEngine *audioEn
 		FailWithAction (0 == featureUnitID, result = kIOReturnSuccess, Exit);	// There isn't a feature unit connected to this output terminal
 		// The interface was opened in AppleUSBAudioEngine::initHardware
 		controlInterface->SetAlternateInterface (this, kRootAlternateSetting);
-		debug2IOLog ("There are %d controls\n", usbAudio->GetNumChannels (interfaceNum, altInterfaceNum));
 		for (channelNum = 0; channelNum <= usbAudio->GetNumChannels (interfaceNum, altInterfaceNum); channelNum++) {
 			if (usbAudio->ChannelHasVolumeControl (controlInterfaceNum, 0, featureUnitID, channelNum)) {
 				micControl = AppleUSBAudioLevelControl::create (featureUnitID,
@@ -599,7 +625,11 @@ IOReturn AppleUSBAudioDevice::activateAudioEngine (IOAudioEngine *audioEngine, b
 
     debug5IOLog ("+AppleUSBAudioDevice[%p]::activateAudioEngine (%p, %d) - rc=%d\n", this, audioEngine, shouldStartAudioEngine, getRetainCount());
 
-    result = super::activateAudioEngine (audioEngine, shouldStartAudioEngine);
+    FailIf (kIOReturnSuccess != super::activateAudioEngine (audioEngine, shouldStartAudioEngine), Exit);
+	result = TRUE;
+
+Exit:
+	flushAudioControls ();
 
     debug4IOLog ("-AppleUSBAudioDevice[%p]::activateAudioEngine (%p) - rc=%d\n", this, audioEngine, getRetainCount ());
     return result;
