@@ -11,37 +11,14 @@
 #ifndef _APPLEUSBAUDIOENGINE_H
 #define _APPLEUSBAUDIOENGINE_H
 
-#include <libkern/OSByteOrder.h>
-#include <libkern/c++/OSCollectionIterator.h>
-#include <libkern/c++/OSMetaClass.h>
-
-#include <IOKit/IOLib.h>
-#include <IOKit/IOSyncer.h>
-#include <IOKit/IOService.h>
-#include <IOKit/IOMessage.h>
-#include <IOKit/IOMemoryCursor.h>
-#include <IOKit/IOMemoryDescriptor.h>
 #include <IOKit/IOBufferMemoryDescriptor.h>
-#include <IOKit/IOTimerEventSource.h>
 #include <IOKit/IOMultiMemoryDescriptor.h>
-
-#include <IOKit/audio/IOAudioDevice.h>
-#include <IOKit/audio/IOAudioPort.h>
-#include <IOKit/audio/IOAudioTypes.h>
-#include <IOKit/audio/IOAudioDefines.h>
-#include <IOKit/audio/IOAudioLevelControl.h>
-//#include <IOKit/audio/IOAudioToggleControl.h>
 #include <IOKit/audio/IOAudioEngine.h>
 #include <IOKit/audio/IOAudioStream.h>
-
 #include <IOKit/usb/IOUSBPipe.h>
 #include <IOKit/usb/IOUSBDevice.h>
 #include <IOKit/usb/IOUSBInterface.h>
-
-#include "AppleUSBAudioCommon.h"
-#include "AppleUSBAudioDevice.h"
-#include "AppleUSBAudioLevelControl.h"
-#include "AppleUSBAudioMuteControl.h"
+#include <IOKit/IOTimerEventSource.h>
 
 #include "USBAudioObject.h"
 #include "AppleiSubEngine.h"
@@ -93,6 +70,8 @@ public:
     virtual IOReturn performAudioEngineStart ();
     virtual IOReturn performAudioEngineStop ();
     
+    virtual IOAudioEngineState _setState (IOAudioEngineState newState);
+
 	static void sampleRateHandler (void * target, void * parameter, IOReturn result, IOUSBIsocFrame * pFrames);
 
     static void readHandler (void * object, void * frameListIndex, IOReturn result, IOUSBLowLatencyIsocFrame * pFrames);
@@ -103,7 +82,6 @@ protected:
 	UInt64								usbFrameToQueueAt;
 	UInt64								nextSynchReadFrame;
 	IOUSBLowLatencyIsocFrame *			theUSBIsocFrames;
-	IOUSBLowLatencyIsocFrame			theStartFrame;
 	IOUSBIsocFrame						theSampleRateFrame;
 	IOUSBLowLatencyIsocCompletion *		usbCompletion;
 	IOUSBIsocCompletion					sampleRateCompletion;
@@ -113,10 +91,13 @@ protected:
 	IOUSBPipe *							theAssociatedPipe;
 	IOSyncer *							signal;
 	AppleUSBAudioDevice *				usbAudioDevice;
-	IOMemoryDescriptor **				soundBufferDescriptors;
-	IOMemoryDescriptor *				theStartBufferDescriptor;
-	IOMemoryDescriptor *				neededSampleRate;
-	IOVirtualRange						theWrapRanges[2];
+	IOBufferMemoryDescriptor *			mUSBBufferDescriptor;
+	IOBufferMemoryDescriptor *			sampleBufferMemoryDescriptor;
+	IOMultiMemoryDescriptor *			theWrapRangeDescriptor;
+	IOSubMemoryDescriptor *				theWrapDescriptors[2];
+	IOSubMemoryDescriptor **			soundBufferDescriptors;
+	IOMemoryDescriptor *				neededSampleRateDescriptor;
+//	IOVirtualRange						theWrapRanges[2];
 	IONotifier *						streamNotifier;
 	OSObject *							interfaceVendor;
 	OSObject *							interfaceProduct;
@@ -126,8 +107,10 @@ protected:
 	void *								readBuffer;
 	void *								theStartBuffer;
 	UInt32 *							aveSampleRateBuf;		// only needs to be 3 bytes for the 10.14 value
+	IOTimerEventSource *				startTimer;
 	thread_call_t						iSubTeardownThreadCall;
 	thread_call_t						iSubOpenThreadCall;
+	thread_call_t						firstUSBFrameCompletionThread;
 	IOAudioSampleRate					curSampleRate;
 	UInt32								previouslyPreparedBufferOffset;
 	UInt32								safeToEraseTo;
@@ -135,6 +118,7 @@ protected:
 	UInt32								theStartBufferSize;
 	UInt32								previous;
 	UInt32								previousClippedToFrame;
+	UInt32								theMaxPacket;
 	UInt32								readUSBFrameListSize;
 	UInt32								bufferOffset;
 	UInt32								averageSampleRate;
@@ -183,6 +167,7 @@ protected:
 	float								srcPhase;
 	float								srcState;
 	Boolean								needToSync;
+	Boolean								needTimeStamps;
 
 	static inline IOFixed IOUFixedDivide(UInt32 a, UInt32 b)
 	{
@@ -203,6 +188,7 @@ protected:
 
     static bool audioDevicePublished (AppleUSBAudioEngine *audioEngine, void *ref, IOService *newService);
     static bool	iSubEnginePublished (AppleUSBAudioEngine * usbAudioEngineObject, void * refCon, IOService * newService);
+	static void waitForFirstUSBFrameCompletion (OSObject * owner, IOTimerEventSource * sender);
 
 	virtual bool willTerminate (IOService * provider, IOOptionBits options);
 
