@@ -1,26 +1,8 @@
 #ifndef _APPLEUSBAUDIOLEVELCONTROL_H
 #define _APPLEUSBAUDIOLEVELCONTROL_H
 
-#include <sys/cdefs.h>
-
-__BEGIN_DECLS
-#include <kern/thread_call.h>
-__END_DECLS
-
-#include <libkern/OSByteOrder.h>
-
-#include <IOKit/IOLib.h>
-#include <IOKit/IOPlatformExpert.h>
-
-#include <IOKit/usb/USB.h>
-#include <IOKit/usb/IOUSBInterface.h>
-
 #include <IOKit/audio/IOAudioLevelControl.h>
-#include <IOKit/audio/IOAudioTypes.h>
-#include <IOKit/audio/IOAudioDefines.h>
-
-#include "AppleUSBAudioCommon.h"
-#include "USBAudioObject.h"
+#include <IOKit/usb/IOUSBInterface.h>
 
 class AppleUSBAudioDevice;
 typedef struct call_entry *thread_call_t;
@@ -29,10 +11,10 @@ typedef IOReturn (*USBDeviceRequest)(IOUSBDevRequest * request, void * refCon =
 
 // PRAM read write values
 enum{
-	kMaximumPRAMVolume 	= 7,
-	kMinimumPRAMVolume	= 0,
-	KNumPramVolumeSteps	= (kMaximumPRAMVolume - kMinimumPRAMVolume + 1),
-	kPRamVolumeAddr	= 8,
+	kMaximumPRAMVolume 	= 	7,
+	kMinimumPRAMVolume	= 	0,
+	KNumPramVolumeSteps	= 	(kMaximumPRAMVolume - kMinimumPRAMVolume + 1),
+	kPRamVolumeAddr	= 		8,
 
 	kDefaultVolume	= 0x006E006E,
 	kInvalidVolumeMask	= 0xFE00FE00
