@@ -151,6 +151,8 @@ bool AppleiSubEngine::openiSub (IOService * forClient) {
 	audioEngine->completeConfigurationChange ();
 	audioEngine->resumeAudioEngine ();
 
+	mNeedToSync = false;	// aml [3095619]
+	
 	resultCode = TRUE;
 
 Exit:
@@ -164,6 +166,8 @@ bool AppleiSubEngine::init (OSDictionary * properties) {
 	debug3IOLog ("+AppleiSubEngine[%p]::init (%p)\n", this, properties);
 
 	resultCode = FALSE;
+	terminatingDriver = FALSE;
+
 	FailIf (FALSE == super::init (properties), Exit);
 
 	resultCode = TRUE;
@@ -225,7 +229,7 @@ bool AppleiSubEngine::start (IOService * provider) {
 	// aml 2.13.02 added num channels and bit depth members, instead of '4'
 	bufferSize = CalculateNumSamplesPerBuffer (mFormat.outputSampleRate, NUM_ISUB_FRAMES_PER_LIST, NUM_ISUB_FRAME_LISTS) * mFormat.numChannels * mFormat.bytesPerSample;
 	debug2IOLog ("bufferSize = %d\n", bufferSize);
-	sampleBuffer = IOMallocAligned (round_page (bufferSize), PAGE_SIZE);
+	sampleBuffer = IOMallocAligned (bufferSize, PAGE_SIZE);
 	FailIf (NULL == sampleBuffer, Exit);
 	// aml 2.13.02 changed from clearing by longs to words
 	for (i = 0; i < bufferSize / sizeof(UInt16); i++) {
@@ -295,6 +299,8 @@ bool AppleiSubEngine::willTerminate (IOService * provider, IOOptionBits options)
 
 	debug5IOLog ("+AppleiSubEngine[%p]::willTerminate (%p, 0x%x) rc =\n", this, provider, options, getRetainCount ());
 
+        terminatingDriver = TRUE;
+
 	if (FALSE == iSubUSBRunning) {
 		// close our stream interface and go away
 		if ((streamInterface != NULL) && (streamInterface == provider)) {
@@ -331,20 +337,7 @@ IOReturn AppleiSubEngine::setPowerState (unsigned long powerStateOrdinal, IOServ
 				break;
 			case 1:		// Power on state
 				debugIOLog ("waking...\n");
-				sleeping = FALSE;
-				// Don't do the reset on this thread because it takes too long.
-/*				if (NULL != streamInterface) {
-					streamInterface->GetDevice()->ResetDevice ();
-					// The ResetDevice causes the iSub to loose its volume and mute states, so put them back.
-					if (NULL != muteControl) {
-						muteControl->flushValue ();
-					}
-	
-					if (NULL != iSubVolumeControl) {
-						iSubVolumeControl->flushValue ();
-					}
-				} */
-	
+				sleeping = FALSE;	
 				result = IOPMNoErr;
 				break;
 			default:
@@ -397,9 +390,9 @@ IOReturn AppleiSubEngine::deviceRequest (IOUSBDevRequest * request, AppleiSubEng
 
 	debug4IOLog ("+AppleiSubEngine[%p]::deviceRequest (%p, %p)\n", self, request, completion);
 	result = kIOReturnSuccess;
-	if (self->streamInterface && request) {
+	if (self->streamInterface && request && (FALSE == self->terminatingDriver)) {
 		result = self->streamInterface->DeviceRequest (request, completion);
-    }
+	}
 
 	debug4IOLog ("-AppleiSubEngine[%p]::deviceRequest (%p, %p)\n", self, request, completion);
 	return result;
@@ -630,6 +623,33 @@ void AppleiSubEngine::WriteHandler (void * object, void * buffer, IOReturn resul
 		self->WriteFrameList (frameListToWrite);
 	}
 
+	// aml - added for [3095619].  Keep track of time differences between calls to monitor scheduling latency
+	// and set the need to sync flag if we are held off for more time than all of our queued data.
+	AbsoluteTime					t_now;
+	AbsoluteTime					t_old;
+	UInt64							nanos_del;
+	t_old.lo = self->mLastTime.lo;
+	t_old.hi = self->mLastTime.hi;
+	clock_get_uptime (&t_now);
+	self->mLastTime.lo = t_now.lo;
+	self->mLastTime.hi = t_now.hi;
+	SUB_ABSOLUTETIME (&t_now, &t_old);		// t_now -= t_old;
+	absolutetime_to_nanoseconds (t_now, &nanos_del);
+
+#if DEBUGLOG
+	nanos_del = nanos_del / (1000);
+	if (nanos_del > 11000) {
+		IOLog ("iSubEngine::WriteHandler - delta = %ld microseconds\n", (UInt32)(nanos_del));
+	} else 	if (nanos_del < 9000) {
+		IOLog ("iSubEngine::WriteHandler - delta = %ld microseconds\n", (UInt32)(nanos_del));
+	}
+#endif
+
+	if (nanos_del > ((NUM_ISUB_FRAME_LISTS_TO_QUEUE * NUM_ISUB_FRAMES_PER_LIST + 1) * 1000 * 1000)) {
+		self->mNeedToSync = true;
+	}	
+	// end added for [3095619]
+	
 Exit:
 	if (TRUE == self->shouldCloseStream) {
 		#if DEBUGLOG
