@@ -207,85 +207,6 @@ enum {
 	PITCH_CONTROL							= 0x02
 };
 
-#if 0
-// Input terminal types
-enum {
-    INPUT_UNDEFINED							= 0x0200,
-    INPUT_MICROPHONE						= 0x0201,
-    INPUT_DESKTOP_MICROPHONE				= 0x0202,
-    INPUT_PERSONAL_MICROPHONE				= 0x0203,
-    INPUT_OMNIDIRECTIONAL_MICROPHONE		= 0x0204,
-    INPUT_MICROPHONE_ARRAY					= 0x0205,
-    INPUT_PROCESSING_MICROPHONE_ARRAY		= 0x0206
-};
-
-// Output terminal types
-enum {
-    OUTPUT_UNDEFINED						= 0x0300,
-    OUTPUT_SPEAKER							= 0x0301,
-    OUTPUT_HEADPHONES						= 0x0302,
-    OUTPUT_HEAD_MOUNTED_DISPLAY_AUDIO		= 0x0303,
-    OUTPUT_DESKTOP_SPEAKER					= 0x0304,
-    OUTPUT_ROOM_SPEAKER						= 0x0305,
-    OUTPUT_COMMUNICATION_SPEAKER			= 0x0306,
-    OUTPUT_LOW_FREQUENCY_EFFECTS_SPEAKER	= 0x0307
-};
-
-// Bi-directional terminal types
-enum {
-    BIDIRECTIONAL_UNDEFINED					= 0x0400,
-    BIDIRECTIONAL_HANDSET					= 0x0401,
-    BIDIRECTIONAL_HEADSET					= 0x0402,
-    BIDIRECTIONAL_SPEAKERPHONE_NO_ECHO_REDX	= 0x0403,
-    BIDIRECTIONAL_ECHO_SUPPRESSING_SPEAKERPHONE	= 0x0404,
-    BIDIRECTIONAL_ECHO_CANCELING_SPEAKERPHONE	= 0x0405
-};
-
-// Telephony terminal types
-enum {
-    TELEPHONY_UNDEFINED						= 0x0500,
-    TELEPHONY_PHONE_LINE					= 0x0501,
-    TELEPHONY_TELEPHONE						= 0x0502,
-    TELEPHONY_DOWN_LINE_PHONE				= 0x0503
-};
-
-// External terminal types
-enum {
-    EXTERNAL_UNDEFINED						= 0x0600,
-    EXTERNAL_ANALOG_CONNECTOR				= 0x0601,
-    EXTERNAL_DIGITAL_AUDIO_INTERFACE		= 0x0602,
-    EXTERNAL_LINE_CONNECTOR					= 0x0603,
-    EXTERNAL_LEGACY_AUDIO_CONNECTOR			= 0x0604,
-    EXTERNAL_SPDIF_INTERFACE				= 0x0605,
-    EXTERNAL_1394_DA_STREAM					= 0x0606,
-    EXTERNAL_1394_DV_STREAM_SOUNDTRACK		= 0x0607
-};
-
-// Embedded terminal types
-enum {
-    EMBEDDED_UNDEFINED						= 0x0700,
-    EMBEDDED_LEVEL_CALIBRATION_NOISE_SOURCE	= 0x0701,
-    EMBEDDED_EQUALIZATION_NOISE				= 0x0702,
-    EMBEDDED_CD_PLAYER						= 0x0703,
-    EMBEDDED_DAT							= 0x0704,
-    EMBEDDED_DCC							= 0x0705,
-    EMBEDDED_MINIDISK						= 0x0706,
-    EMBEDDED_ANALOG_TAPE					= 0x0707,
-    EMBEDDED_PHONOGRAPH						= 0x0708,
-    EMBEDDED_VCR_AUDIO						= 0x0709,
-    EMBEDDED_VIDEO_DISC_AUDIO				= 0x070A,
-    EMBEDDED_DVD_AUDIO						= 0x070B,
-    EMBEDDED_TV_TUNER_AUDIO					= 0x070C,
-    EMBEDDED_SATELLITE_RECEIVER_AUDIO		= 0x070D,
-    EMBEDDED_CABLE_TUNER_AUDIO				= 0x070E,
-    EMBEDDED_DSS_AUDIO						= 0x070F,
-    EMBEDDED_RADIO_RECEIVER					= 0x0710,
-    EMBEDDED_RADIO_TRANSMITTER				= 0x0711,
-    EMBEDDED_MULTITRACK_RECORDER			= 0x0712,
-    EMBEDDED_SYNTHESIZER					= 0x0713
-};
-#endif
-
 #define USB_AUDIO_IS_FUNCTION(subtype)	((subtype >= MIXER_UNIT) && (subtype <= EXTENSION_UNIT))
 #define USB_AUDIO_IS_TERMINAL(subtype)	((subtype == INPUT_TERMINAL) || (subtype == OUTPUT_TERMINAL))
 
@@ -352,7 +273,7 @@ typedef struct ACInterfaceHeaderDescriptor {
     UInt8									bDescriptorType;
     UInt8									bDescriptorSubtype;
     UInt8									bcdADC;
-    UInt16									wTotalLength;
+    UInt16									wTotalLength; 
     UInt8									bInCollection;
     UInt8									baInterfaceNr[1];			// There are bInCollection of these
 } ACInterfaceHeaderDescriptor, *ACInterfaceHeaderDescriptorPtr;
@@ -377,7 +298,7 @@ typedef struct ACInputTerminalDescriptor {
     UInt16									wTerminalType;
     UInt8									bAssocTerminal;
     UInt8									bNrChannels;
-    UInt16									wChannelConfig;
+    UInt16									wChannelConfig; 
     UInt8									iChannelNames;
     UInt8									iTerminal;
 } ACInputTerminalDescriptor, *ACInputTerminalDescriptorPtr;
@@ -755,7 +676,7 @@ private:
     Boolean							pitchControl;
     Boolean							maxPacketsOnly;
     UInt8							lockDelayUnits;
-    UInt16							lockDelay;
+	UInt16							lockDelay;
     UInt8							attributes;
 
 	// You shouldn't need to get the attributes directly, instead use DoesMaxPacketsOnly (), HasPitchControl (), and HasSampleFreqControl ()
@@ -782,7 +703,7 @@ private:
 
     UInt32 *						sampleFreqs;
 	UInt32							bmAC3BSID;
-	UInt16							bmMPEGCapabilities;
+	UInt16							bmMPEGCapabilities; 
     UInt16							formatTag;
 	UInt16							maxBitRate;
 	UInt16							samplesPerFrame;
